# -*- coding: utf8 -*-
from __future__ import unicode_literals

from driverng.protocol.astm import AstmProtocol
from driverng.protocol.advia import AdviaProtocol
from driverng.protocol.void import VoidProtocol
from driverng.protocol.mllp import MLLPProtocol
from driverng.protocol.acknack import ACKNACKProtocol
from driverng.protocol.dimension import DimensionProtocol
from driverng.protocol.vscube import VSCubeProtocol
from driverng.protocol.abx import AbxProtocol
from driverng.protocol.tosoh import TosohProtocol
from driverng.protocol.cd3200 import Cd3200Protocol
from driverng.protocol.bci import BCIProtocol
from driverng.protocol.alifax import AlifaxProtocol
from driverng.protocol.phoresys import PhoresysProtocol
from driverng.protocol.rapidlab import RapidlabProtocol
from driverng.protocol.noastm import NoAstmProtocol
from driverng.protocol.kermit import KermitProtocol
from driverng.protocol.lh import LHProtocol
from driverng.protocol.ha81 import Ha81Protocol
from driverng.protocol.au680 import Au680Protocol
from driverng.protocol.pvs import PvsProtocol
from driverng.protocol.bn2 import BN2SerHostProtocol, BN2AutoHostProtocol
from driverng.protocol.sedimax import SedimaxProtocol
from driverng.protocol.vt_syslab import VtSyslabProtocol
from driverng.protocol.valab import ValabProtocol
from driverng.protocol.walkaway import WalkawayProtocol
from driverng.protocol.dm_astm import DmAstmProtocol
from driverng.protocol.atellica import AtellicaProtocol
from driverng.protocol.hl7poc import Hl7PocProtocol
from driverng.protocol.starlet import StarletProtocol


PROTOCOLES = {
    "astm": AstmProtocol,
    "advia2120": AdviaProtocol,
    "void": VoidProtocol,
    "mllp": MLLPProtocol,
    "acknack": ACKNACKProtocol,
    "dimension": DimensionProtocol,
    "vscube": VSCubeProtocol,
    "abx": AbxProtocol,
    "tosoh": TosohProtocol,
    "cd3200": Cd3200Protocol,
    "bci": BCIProtocol,
    "alifax": AlifaxProtocol,
    "phoresys": PhoresysProtocol,
    "rapidlab": RapidlabProtocol,
    "noastm": NoAstmProtocol,
    "kermit": KermitProtocol,
    "lh": LHProtocol,
    "ha81": Ha81Protocol,
    "au680": Au680Protocol,
    "pvs": PvsProtocol,
    "bn2_serhost": BN2SerHostProtocol,
    "bn2_autohost": BN2AutoHostProtocol,
    "sedimax": SedimaxProtocol,
    "vt_syslab": VtSyslabProtocol,
    "valab": ValabProtocol,
    "walkaway": WalkawayProtocol,
    "dm_astm": DmAstmProtocol,
    "atellica": AtellicaProtocol,
    "hl7poc": Hl7PocProtocol,
    "starlet": StarletProtocol,
}


def get(**kwargs):
    kwargs = kwargs.copy()
    protocol_type = kwargs.pop("type")
    if "encoding" not in kwargs:
        kwargs["encoding"] = "ISO-8859-15"
    return PROTOCOLES[protocol_type](**kwargs)
